"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultConfigureGenerator = void 0;
const path_1 = __importDefault(require("path"));
const inquirer_autocomplete_prompt_1 = __importDefault(require("inquirer-autocomplete-prompt"));
const through2 = require("through2");
const prettier = require("prettier");
// Moved (almost) unchanged from src/common
const defaultConfigureGenerator = (templateDir, gen, options) => {
    const { dest } = options;
    if (dest != null) {
        gen.destinationRoot(path_1.default.isAbsolute(dest) ? dest : path_1.default.join(gen.destinationRoot(), dest));
    }
    const { templateOverride } = options;
    gen.sourceRoot(templateOverride ?? templateDir);
    // @ts-ignore this.env.adapter is missing in the typings
    gen.env.adapter
        .promptModule.registerPrompt('autocomplete', inquirer_autocomplete_prompt_1.default);
    gen.registerTransformStream(createEjsRenameTransform());
    gen.registerTransformStream(createFormatTransform());
    // Never ask for confirmation when overwriting files,
    // since currently we only support using generator from Studio.
    // If in future we decide to support using generator from CLI, we need to revisit this.
    gen.conflicter.force = true;
};
exports.defaultConfigureGenerator = defaultConfigureGenerator;
/**
 * Transform stream for remove .ejs extension from files. We are using this extension to improve code
 * highlight in editor
 */
function createEjsRenameTransform() {
    return through2.obj(function (file, enc, callback) {
        file.basename = file.basename
            .replace(/.ts.ejs$/, '.ts')
            .replace(/.tsx.ejs$/, '.tsx');
        this.push(file);
        callback();
    });
}
/**
 * Prettier formatting transform stream for .ts and .tsx files
 */
function createFormatTransform() {
    return through2.obj(function (file, enc, callback) {
        if ((file.path.endsWith('.ts') || file.path.endsWith('.tsx')) && file.contents != null) {
            const contents = Buffer.from(file.contents).toString('utf8');
            // for imports sort and optimization we are using https://github.com/simonhaenisch/prettier-plugin-organize-imports
            // no additional config required, plugin is applied automatically,
            // if installed in node_modules (check package.json)
            // to disable plugin usage pass `pluginSearchDirs: false` in `options`
            file.contents = Buffer.from(prettier.format(contents, {
                parser: "typescript",
                printWidth: 100
            }));
        }
        this.push(file);
        callback();
    });
}
//# sourceMappingURL=defaultConfigureGenerator.js.map