"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGraphQLTypeByRelativePath = void 0;
const graphql_1 = require("graphql");
/**
 * Getting graphQL type by relative path from another nested graphQL type
 *
 * @param schema - graphQL schema
 * @param type - type of graphQL schema
 * @param path - path to nested type
 *
 * @returns - GraphQLType of nested type got by path
 */
function getGraphQLTypeByRelativePath(schema, type, path) {
    if (path.length === 0) {
        return type;
    }
    const [head, ...tail] = path;
    const currentGraphQLType = schema.getType(graphql_1.getNamedType(type).name);
    if (!(currentGraphQLType instanceof graphql_1.GraphQLObjectType
        || currentGraphQLType instanceof graphql_1.GraphQLInputObjectType
        || currentGraphQLType instanceof graphql_1.GraphQLInterfaceType)) {
        throw new Error(`${type.toString()} don't have fields for getting GraphQL Type by path`);
    }
    const headField = currentGraphQLType.getFields()[head];
    if (headField === undefined) {
        throw new Error(`Path doesn't exist for '${head}'`);
    }
    return getGraphQLTypeByRelativePath(schema, headField.type, tail);
}
exports.getGraphQLTypeByRelativePath = getGraphQLTypeByRelativePath;
//# sourceMappingURL=getGraphQLTypeByRelativePath.js.map