"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resetAuth = void 0;
const deleteFiles_1 = require("../deleteFiles");
const removeEnvVar_1 = require("../source-utils/variables/removeEnvVar");
const replaceStringValue_1 = require("../source-utils/variables/replaceStringValue");
const removeVarExport_1 = require("../source-utils/variables/removeVarExport");
const updateNpmDeps_1 = require("../npm/updateNpmDeps");
const writeTemplate_1 = require("../writeTemplate");
const path_1 = __importDefault(require("path"));
const authDeps_1 = require("./authDeps");
/**
 * Deletes all auth-related specifics.
 * To be used in auth-* generators in order to reset the project code to a known state
 * before modifying it.
 *
 * @param gen
 * @param templateModel
 * @param newDeps - deps to used in new auth
 */
async function resetAuth(gen, templateModel, newDeps) {
    // Delete auth-related code:
    // - Apollo links
    await deleteFiles_1.deleteFiles(gen, './src/core/apollo/links/authLink.ts');
    await deleteFiles_1.deleteFiles(gen, './src/core/apollo/links/httpLink.ts');
    // - server error handling
    await deleteFiles_1.deleteFiles(gen, './src/core/error/ServerErrorInterceptor.ts');
    // - security folder
    await deleteFiles_1.deleteFiles(gen, './src/core/security/Auth.tsx');
    await deleteFiles_1.deleteFiles(gen, './src/core/security/oidcConfig.ts');
    await deleteFiles_1.deleteFiles(gen, './src/core/security/SecurityProvider.tsx');
    await deleteFiles_1.deleteFiles(gen, './src/core/security/SecurityStore.ts');
    await deleteFiles_1.deleteFiles(gen, './src/core/security/login');
    // - dev
    await deleteFiles_1.deleteFiles(gen, './src/dev/performDevLogin.ts');
    // Remove auth-related env variables
    // - .env.development
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.development', 'VITE_LOGIN_URI');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.development', 'VITE_LOGOUT_URI');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.development', 'VITE_REQUEST_SAME_ORIGIN');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.development', 'VITE_DEV_LOGIN');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.development', 'VITE_DEV_PASSWORD');
    // - .env.production
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.production', 'VITE_LOGIN_URI');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.production', 'VITE_LOGOUT_URI');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.production', 'VITE_REQUEST_SAME_ORIGIN');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.production', 'VITE_DEV_LOGIN');
    await removeEnvVar_1.removeEnvVarInFile(gen, './.env.production', 'VITE_DEV_PASSWORD');
    // - src/config.ts
    await removeVarExport_1.removeVarExportInFile(gen, './src/config.ts', 'LOGIN_URI');
    await removeVarExport_1.removeVarExportInFile(gen, './src/config.ts', 'LOGOUT_URI');
    await removeVarExport_1.removeVarExportInFile(gen, './src/config.ts', 'REQUEST_SAME_ORIGIN');
    await removeVarExport_1.removeVarExportInFile(gen, './src/config.ts', 'DEV_LOGIN');
    await removeVarExport_1.removeVarExportInFile(gen, './src/config.ts', 'DEV_PASSWORD');
    // We don't touch vite-env.d.ts to simplify the process a bit
    // Reset proxy endpoints to just "graphql"
    await replaceStringValue_1.replaceStringValueInFile(gen, './vite.config.ts', 'AMPLICODE_ENDPOINTS', 'graphql');
    await updateNpmDeps_1.updateNpmDeps(gen, Object.entries(authDeps_1.AUTH_DEPS).map(([[propName]]) => propName), newDeps);
    // Reset some files to defaults from ./template/**
    await writeTemplate_1.writeTemplate(gen, templateModel, path_1.default.join(__dirname, 'template'));
    await deleteFiles_1.deleteFiles(gen, './src/non-existing-file'); // TODO remove
}
exports.resetAuth = resetAuth;
//# sourceMappingURL=resetAuth.js.map