"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const parseExpression_1 = require("./parseExpression");
describe('parseExpression', () => {
    it('Struct of primitives', () => {
        const stringExpression = parseExpression_1.parseExpression(`"string"`);
        chai_1.expect(stringExpression.type).eq("StringLiteral");
        if (stringExpression.type === 'StringLiteral') {
            chai_1.expect(stringExpression.value).eq("string");
        }
        const numberExpression = parseExpression_1.parseExpression('0');
        chai_1.expect(numberExpression.type).eq("NumericLiteral");
        if (numberExpression.type === 'NumericLiteral') {
            chai_1.expect(numberExpression.value).eq(0);
        }
        const boolExpression = parseExpression_1.parseExpression('true');
        chai_1.expect(boolExpression.type).eq("BooleanLiteral");
        if (boolExpression.type === 'BooleanLiteral') {
            chai_1.expect(boolExpression.value).eq(true);
        }
    });
    it('Struct of object', () => {
        const object = parseExpression_1.parseExpression(`{
      number: 0,
      string: "string",
    }`);
        if (object.type === 'ObjectExpression') {
            if (object.properties[0].type === 'ObjectProperty') {
                if (object.properties[0].key.type === 'Identifier') {
                    chai_1.expect(object.properties[0].key.name).eq('number');
                }
                if (object.properties[0].value.type === 'NumericLiteral') {
                    chai_1.expect(object.properties[0].value.value).eq(0);
                }
            }
            if (object.properties[1].type === 'ObjectProperty') {
                if (object.properties[1].key.type === 'Identifier') {
                    chai_1.expect(object.properties[1].key.name).eq('string');
                }
                if (object.properties[1].value.type === 'StringLiteral') {
                    chai_1.expect(object.properties[1].value.value).eq('string');
                }
            }
        }
    });
    it('Struct of array', () => {
        const array = parseExpression_1.parseExpression('[0, "string", true]');
        chai_1.expect(array.type).eq('ArrayExpression');
        if (array.type === 'ArrayExpression') {
            if (array.elements[0]?.type === 'NumericLiteral') {
                chai_1.expect(array.elements[0].value).eq(0);
            }
            if (array.elements[1]?.type === 'StringLiteral') {
                chai_1.expect(array.elements[1].value).eq('string');
            }
            if (array.elements[2]?.type === 'BooleanLiteral') {
                chai_1.expect(array.elements[2].value).eq(true);
            }
        }
    });
    it('Struct of jsx', () => {
        const jsx = parseExpression_1.parseExpression('<div numberProp={0}>{"childText"}</div>');
        chai_1.expect(jsx.type).eq("JSXElement");
        if (jsx.type === 'JSXElement') {
            if (jsx.openingElement.type === 'JSXOpeningElement') {
                if (jsx.openingElement.name.type === 'JSXIdentifier') {
                    chai_1.expect(jsx.openingElement.name.name).eq('div');
                }
                if (jsx.openingElement.attributes?.[0].type === 'JSXAttribute') {
                    chai_1.expect(jsx.openingElement.attributes?.[0].name.name).eq('numberProp');
                }
            }
            if (jsx.closingElement?.type === 'JSXClosingElement') {
                if (jsx.closingElement.name.type === 'JSXIdentifier') {
                    chai_1.expect(jsx.closingElement.name.name).eq('div');
                }
            }
            if (jsx.children?.[0].type === 'JSXExpressionContainer') {
                if (jsx.children?.[0].expression.type === 'StringLiteral') {
                    chai_1.expect(jsx.children?.[0].expression.value).eq("childText");
                }
            }
        }
    });
});
//# sourceMappingURL=parseExpression.test.js.map