"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addScreenI18nKeyEn = exports.writeAmplicodeComponent = void 0;
const path_1 = __importDefault(require("path"));
const utils_1 = require("../../../../../common/utils");
const addMvpAppMenu_1 = require("./addMvpAppMenu");
const previews_registration_1 = require("../previews-registration");
async function writeAmplicodeComponent(templateModel, gen, srcPath, writeI18n = true, writePreview = true) {
    const { relDirShift, componentName, route, routeType, shouldAddToMenu, menuItemName } = templateModel;
    gen.log(`Generating '${componentName}' to '${gen.destinationPath()}'`);
    gen.fs.copyTpl(srcPath, gen.destinationPath(componentName + '.tsx'), templateModel);
    if (shouldAddToMenu && route != null) {
        addMvpAppMenu_1.addMvpAppMenu({
            gen,
            dirShift: relDirShift,
            route,
            routeType,
            componentName,
            menuItemName
        });
    }
    else {
        // TODO get back after separating RA writing method
        // gen.log(`✓ Menu item not required for ${componentName}`);
    }
    if (writeI18n) {
        addScreenI18nKeyEn(componentName, relDirShift, gen);
        gen.log(`✓ i18n messages added for ${componentName}`);
    }
    if (writePreview) {
        previews_registration_1.addComponentPreviews(gen, relDirShift, componentName, componentName);
        gen.log(`✓ Component previews added for ${componentName}`);
    }
}
exports.writeAmplicodeComponent = writeAmplicodeComponent;
function addScreenI18nKeyEn(className, dirShift, gen, componentType = "screen") {
    const existingMessagesPath = path_1.default.join(dirShift, 'core', 'i18n', 'messages', 'en.json');
    const existingMessages = gen.fs.readJSON(existingMessagesPath);
    if (existingMessages == null) {
        throw new Error('i18n messages not found');
    }
    const screenNameKey = `${componentType}.${className}`;
    if (Object.keys(existingMessages).includes(screenNameKey)) {
        return;
    }
    const screenCaption = utils_1.splitByCapitalLetter(utils_1.capitalizeFirst(className));
    const mergedMessages = {
        ...existingMessages,
        [screenNameKey]: screenCaption
    };
    gen.fs.writeJSON(existingMessagesPath, mergedMessages);
}
exports.addScreenI18nKeyEn = addScreenI18nKeyEn;
//# sourceMappingURL=mvp.js.map