"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const addResourceToMenu_1 = require("./addResourceToMenu");
const chai_1 = require("chai");
describe("addResourceToMenu", () => {
    const MENU_INPUT = `
    <Menu>
      <Menu.DashboardItem />
      <Menu.ResourceItem name="OwnerDTO" />
      <Menu.ResourceItem name="PetTypeDTO" />
    </Menu>
  `;
    it("should add resource item to menu, if item not exist", function () {
        const resourceName = "NewEntityDTO";
        const res = addResourceToMenu_1.addResourceToMenu(MENU_INPUT, resourceName);
        chai_1.expect(res).to.contain(`<Menu.ResourceItem name="NewEntityDTO" />`);
    });
    it("should add resource item to empty menu", function () {
        const resourceName = "NewEntityDTO";
        const res = addResourceToMenu_1.addResourceToMenu(`<Menu></Menu>`, resourceName);
        chai_1.expect(res).to.contain(`<Menu.ResourceItem name="NewEntityDTO" />`);
    });
    // TODO
    xit("should add resource item to empty self-closing menu", function () {
        const resourceName = "NewEntityDTO";
        const res = addResourceToMenu_1.addResourceToMenu(`<Menu/>`, resourceName);
        chai_1.expect(res).to.contain(`<Menu.ResourceItem name="NewEntityDTO" />`);
    });
    it("should do nothing if resource item already in menu", function () {
        const resourceName = "OwnerDTO";
        const res = addResourceToMenu_1.addResourceToMenu(MENU_INPUT, resourceName);
        chai_1.expect(res).to.eq(MENU_INPUT);
    });
    it("should fail for incorrect input", function () {
        const resourceName = "OwnerDTO";
        chai_1.expect(addResourceToMenu_1.addResourceToMenu.bind(undefined, `Not jsx`, resourceName)).to.throw();
        const emptyJsx = '';
        chai_1.expect(addResourceToMenu_1.addResourceToMenu.bind(undefined, emptyJsx, resourceName)).to.throw();
    });
    it("should fail if Menu tag not found", function () {
        const resourceName = "OwnerDTO";
        chai_1.expect(addResourceToMenu_1.addResourceToMenu.bind(undefined, `<NotMenuTag></NotMenuTag>`, resourceName)).to.throw();
    });
});
//# sourceMappingURL=addResourceToMenu.test.js.map