"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addScreenToAdminUi = void 0;
const jscodeshift_1 = __importStar(require("jscodeshift"));
const change_case_1 = require("change-case");
const path_1 = __importDefault(require("path"));
const recordRepresentationFunctionName_1 = require("../../../../../generators/react-admin/common/recordRepresentation/recordRepresentationFunctionName");
function addScreenToAdminUi(appTsxInput, resourceName, screenName, screenType, screenImportPath) {
    const tsxParser = jscodeshift_1.default.withParser("tsx");
    const appAST = tsxParser(appTsxInput);
    const adminUi = appAST.findJSXElements("AdminUI");
    if (adminUi == null) {
        console.error(`addScreenToAdminUi: no 'AdminUI' tag found in input\n`, appTsxInput);
        throw new Error(`No 'AdminUI' tag found in input`);
    }
    if (adminUi.paths().length != 1) {
        console.error(`addScreenToAdminUi: menu.paths() should contains only one element`);
        throw new Error(`Incorrect data in 'menu.paths()'`);
    }
    const children = adminUi.paths()[0].value.children;
    if (children == null) {
        console.error(`addScreenToAdminUi: 'children' is undefined in input\n`, appTsxInput);
        throw new Error(`Parsing 'AdminUI' tag failed - 'children' is undefined`);
    }
    // try to find already existed <Resource name={resourceName}> tag in AdminUI
    const resourceItem = children
        .filter(el => el.type === jscodeshift_1.default.JSXElement.toString())
        .find(el => {
        const openingEl = el.openingElement;
        return openingEl?.name?.name === "Resource" &&
            openingEl?.attributes?.some((attr) => attr.name?.name === "name" && attr.value?.value === resourceName);
    });
    if (resourceItem != null) {
        console.log(`addScreenToAdminUi: skip adding resource item to AdminUI tag, item ${resourceName} already exist`);
        const openingEl = resourceItem.openingElement;
        // try to find attribute, named as screenType in Resource tag
        const screenAttr = openingEl?.attributes?.find((attr) => attr.name.name === screenType);
        if (screenAttr != null) {
            // screen with such type already exist in Resource - overwrite attr value
            screenAttr.value = jscodeshift_1.default.jsxExpressionContainer(jscodeshift_1.default.jsxIdentifier(screenName));
            console.log(`addScreenToAdminUi: update attribute value to ${screenType}={ ${screenName} }'` +
                ` in ${resourceName} resource tag`);
        }
        else {
            // attribute for such screen type doesn't exist in Resource tag
            // add attribute `screenType={screenName}` to Resource tag
            // result example `<Resource create={ PetCreateAdvanced } />`
            const newScreenAttr = jscodeshift_1.default.jsxAttribute(jscodeshift_1.default.jsxIdentifier(screenType), jscodeshift_1.default.jsxExpressionContainer(jscodeshift_1.default.jsxIdentifier(screenName)));
            openingEl.attributes.push(newScreenAttr);
            console.log(`addScreenToAdminUi: attribute '${screenType}={ ${screenName} }' ` +
                `added to ${resourceName} resource tag`);
        }
    }
    else {
        createResourceTag(resourceName, screenType, screenName, children);
    }
    // find 'react-admin' import declaration
    const raImportDeclaration = appAST
        .find(jscodeshift_1.default.ImportDeclaration)
        .filter(path => {
        return path.value.source.value === 'react-admin';
    });
    const raImportSpecifiers = raImportDeclaration.paths()[0].value.specifiers;
    if (!raImportSpecifiers.some(specifier => specifier.imported.name === 'Resource')) {
        raImportSpecifiers.push(jscodeshift_1.importSpecifier(jscodeshift_1.default.identifier('Resource')));
        console.log(`addScreenToAdminUi: adding import from 'react-admin' of Resource tag`);
    }
    else {
        console.log(`addScreenToAdminUi: skip adding import from 'react-admin' of Resource tag, already exist`);
    }
    addScreenImport(appAST, screenName, screenImportPath);
    addRecordRepresentationFunctionImport(appAST, resourceName);
    return appAST.toSource();
}
exports.addScreenToAdminUi = addScreenToAdminUi;
function createResourceTag(resourceName, screenType, screenName, 
// TODO remove children from args
children) {
    const label = change_case_1.capitalCase(resourceName);
    const resourceItemTag = `` +
        `<Resource\n` +
        `  name="${resourceName}"\n` +
        `  options={{ label: "${label}" }}\n` +
        `  ${screenType}={${screenName}}\n` +
        `  recordRepresentation={${recordRepresentationFunctionName_1.recordRepresentationFunctionName(resourceName)}} />`;
    children?.push(jscodeshift_1.default.stringLiteral(resourceItemTag));
    console.log(`addScreenToAdminUi: adding item to AdminUI tag \n${resourceItemTag} `);
}
function addScreenImport(appAST, screenName, screenImportPath) {
    const screenImportSpecifiers = appAST.find(jscodeshift_1.default.ImportDeclaration)
        .find(jscodeshift_1.default.ImportSpecifier)
        .filter(path => path.node.imported.name === screenName);
    const screenAlreadyImported = screenImportSpecifiers.length > 0;
    let importPath = path_1.default.join(screenImportPath, screenName);
    if (!importPath.startsWith(".")) {
        importPath = "./" + importPath;
    }
    if (!screenAlreadyImported) {
        const screenImport = jscodeshift_1.default.importDeclaration([jscodeshift_1.importSpecifier(jscodeshift_1.default.identifier(screenName))], jscodeshift_1.default.stringLiteral(importPath));
        appAST.get().node.program.body.unshift(screenImport);
        console.log(`addScreenToAdminUi: add import for screen '${screenName}' with import path '${importPath}' to App.tsx`);
    }
    else {
        console.log(`addScreenToAdminUi: skip adding import for screen '${screenName}' with import path '${importPath}', ` +
            `import already exist in App.tsx`);
    }
}
function addRecordRepresentationFunctionImport(appAST, resourceName) {
    const recordRepFunctionName = recordRepresentationFunctionName_1.recordRepresentationFunctionName(resourceName);
    const recordRepImportPath = `../core/record-representation/${recordRepFunctionName}`;
    const recordRepImportSpecifiers = appAST.find(jscodeshift_1.default.ImportDeclaration)
        .find(jscodeshift_1.default.ImportSpecifier)
        .filter(path => path.node.imported.name === recordRepFunctionName);
    const recordRepImported = recordRepImportSpecifiers.length > 0;
    if (!recordRepImported) {
        const recordRepImport = jscodeshift_1.default.importDeclaration([jscodeshift_1.importSpecifier(jscodeshift_1.default.identifier(recordRepFunctionName))], jscodeshift_1.default.stringLiteral(recordRepImportPath));
        appAST.get().node.program.body.unshift(recordRepImport);
        console.log(`addScreenToAdminUi: add import for record representation function '${recordRepFunctionName}' ` +
            `with import path '${recordRepImportPath}' to App.tsx`);
    }
    else {
        console.log(`addScreenToAdminUi: skip adding import for record representation '${recordRepFunctionName}' ` +
            `with import path '${recordRepImportPath}', import already exist in App.tsx`);
    }
}
//# sourceMappingURL=addScreenToAdminUi.js.map