"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceEnvVarValue = exports.replaceEnvVarValueInFile = void 0;
const ReplacementTargetNotFoundError_1 = require("./ReplacementTargetNotFoundError");
async function replaceEnvVarValueInFile(gen, fileName, variableName, newValue) {
    const filePath = gen.destinationPath(fileName);
    const source = gen.fs.read(filePath);
    let output = source;
    try {
        output = replaceEnvVarValue(source, variableName, newValue);
    }
    catch (error) {
        if (error instanceof ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError) {
            gen.log(`WARNING: Was trying to change ${variableName} in "${filePath}" to "${newValue}", but this file does not contain this variable. This may break the application.`);
            return;
        }
        throw error;
    }
    await gen.fs.write(filePath, output);
}
exports.replaceEnvVarValueInFile = replaceEnvVarValueInFile;
function replaceEnvVarValue(source, variableName, newValue) {
    const regex = new RegExp(`^${variableName}=(.*)$`, 'm');
    if (!regex.test(source)) {
        throw new ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError();
    }
    return source.replace(regex, `${variableName}=${newValue}`);
}
exports.replaceEnvVarValue = replaceEnvVarValue;
//# sourceMappingURL=replaceEnvVarValue.js.map