"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pickOptions = exports.extractAvailableOptions = exports.componentOptionsConfig = exports.commonGenerationOptionsConfig = void 0;
exports.commonGenerationOptionsConfig = {
    dest: {
        alias: 'd',
        description: 'destination directory',
        type: String
    },
    model: {
        alias: 'm',
        description: 'specify path to project model, if given no interactive prompt will be invoked',
        type: String
    },
    verbose: {
        alias: 'b',
        description: 'log out additional info about generation process',
        type: Boolean
    }
};
exports.componentOptionsConfig = {
    ...exports.commonGenerationOptionsConfig,
    dirShift: {
        alias: 'f',
        description: 'directory shift for html imports e.g ../../',
        type: String
    },
    answers: {
        alias: 'a',
        description: 'fulfilled params for generator to avoid interactive input in serialized JSON string',
        type: String
    }
};
/**
 * Convert 'OptionsConfig' object to array of items that could be used in generator cli api
 * @param optionsConfig
 */
function extractAvailableOptions(optionsConfig) {
    if (!optionsConfig) {
        return [];
    }
    const result = [];
    Object.keys(optionsConfig).forEach(optionFullName => {
        const { type, alias, description } = optionsConfig[optionFullName];
        if (alias) {
            const optionValue = getOptionValue(type, optionFullName);
            const pattern = `-${alias}, --${optionFullName}${optionValue}`;
            description ? result.push({ pattern, description }) : result.push({ pattern });
        }
    });
    return result;
}
exports.extractAvailableOptions = extractAvailableOptions;
/**
 * Pick  option as object from command
 *
 * @param cmd list of options from cli command
 * @param availableOptions options config
 */
function pickOptions(cmd, availableOptions) {
    const passedOptions = {};
    if (availableOptions) {
        Object.keys(availableOptions).forEach(optionFullName => {
            // eslint-disable-next-line no-prototype-builtins
            if (cmd.hasOwnProperty(optionFullName)) {
                passedOptions[optionFullName] = cmd[optionFullName];
            }
        });
    }
    return passedOptions;
}
exports.pickOptions = pickOptions;
function getOptionValue(type, optionFullName) {
    if (type === String) {
        return ` [${optionFullName}]`;
    }
    // @ts-ignore TODO: fix yeoman-generator typing
    if (type === Array) {
        return ` [${optionFullName}...]`;
    }
    return '';
}
//# sourceMappingURL=cli-options.js.map