"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeAuthFormLogin = void 0;
const replaceStringValue_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/variables/replaceStringValue");
const appendCode_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/appendCode");
const addEnvVar_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/variables/addEnvVar");
const path_1 = __importDefault(require("path"));
const writeAppTemplate_1 = require("../common/writeAppTemplate");
async function writeAuthFormLogin(templateModel, gen) {
    // write files from 'app' generator template folder
    await writeAppTemplate_1.writeAppTemplate(gen, path_1.default.join('src', 'index.tsx'));
    await writeAppTemplate_1.writeAppTemplate(gen, path_1.default.join('src', 'authProvider', 'authProvider.ts'));
    await writeAppTemplate_1.writeAppTemplate(gen, path_1.default.join('src', 'authProvider', 'useAuthProvider.ts'));
    await writeAppTemplate_1.writeAppTemplate(gen, path_1.default.join('src', 'core', 'apollo', 'links', 'httpLink.ts'));
    await writeAppTemplate_1.writeAppTemplate(gen, path_1.default.join('src', 'core', 'apollo', 'links', 'authLink.ts'));
    // Add login/logout endpoints
    await replaceStringValue_1.replaceStringValueInFile(gen, 'vite.config.ts', 'AMPLICODE_ENDPOINTS', 'graphql|login|logout');
    // Add environment variables
    const envVarConfig = `export const LOGIN_URI = import.meta.env.VITE_LOGIN_URI ?? "/login";
  export const LOGOUT_URI = import.meta.env.VITE_LOGOUT_URI ?? "/logout";
  export const REQUEST_SAME_ORIGIN =
    import.meta.env.VITE_REQUEST_SAME_ORIGIN ?? true;
  export const DEV_LOGIN = import.meta.env.VITE_DEV_LOGIN ?? "admin";
  export const DEV_PASSWORD = import.meta.env.VITE_DEV_PASSWORD ?? "admin";`;
    await appendCode_1.appendCodeInFile(gen, 'src/config.ts', envVarConfig);
    for (const fileName of ['.env.development', '.env.production']) {
        await addEnvVar_1.addEnvVarInFile(gen, fileName, 'VITE_LOGIN_URI', '/login');
        await addEnvVar_1.addEnvVarInFile(gen, fileName, 'VITE_LOGOUT_URI', '/logout');
        await addEnvVar_1.addEnvVarInFile(gen, fileName, 'VITE_REQUEST_SAME_ORIGIN', 'true');
        await addEnvVar_1.addEnvVarInFile(gen, fileName, 'VITE_DEV_LOGIN', 'admin');
        await addEnvVar_1.addEnvVarInFile(gen, fileName, 'VITE_DEV_PASSWORD', 'admin');
    }
}
exports.writeAuthFormLogin = writeAuthFormLogin;
//# sourceMappingURL=write.js.map