"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.raResetAuth = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const removeEnvVarInFile_1 = require("./removeEnvVarInFile");
const removeVarExportInFile_1 = require("./removeVarExportInFile");
const replaceStringValueInFile_1 = require("./replaceStringValueInFile");
const npmDeps_1 = require("./npmDeps");
const auth_oidc_keycloak_1 = require("../../auth-oidc-keycloak");
function raResetAuth(dest) {
    console.log("raResetAuth: dest ", dest);
    // delete files
    deleteFileSync(path_1.default.join(dest, "src", "authProvider"));
    deleteFileSync(path_1.default.join(dest, "src", "core", "apollo", "links", "httpLink.ts"));
    deleteFileSync(path_1.default.join(dest, "src", "core", "apollo", "links", "authLink.ts"));
    deleteFileSync(path_1.default.join(dest, "src", "core", "security"));
    deleteFileSync(path_1.default.join(dest, "src", "index.tsx"));
    // remove env vars
    const envVarsToRemove = ['VITE_LOGIN_URI', 'VITE_LOGOUT_URI', 'VITE_REQUEST_SAME_ORIGIN', 'VITE_DEV_LOGIN', 'VITE_DEV_PASSWORD',
        'VITE_OIDC_CONFIG_SCOPE', 'VITE_OIDC_CONFIG_CLIENT_ID', 'VITE_OIDC_CONFIG_AUTHORITY'];
    removeEnvVarInFile_1.removeEnvVarInFile(path_1.default.join(dest, './.env.development'), envVarsToRemove);
    removeEnvVarInFile_1.removeEnvVarInFile(path_1.default.join(dest, './.env.production'), envVarsToRemove);
    const varExportsToRemove = ['LOGIN_URI', 'LOGOUT_URI', 'DEV_PASSWORD', 'DEV_LOGIN', 'REQUEST_SAME_ORIGIN'];
    // - src/config.ts
    removeVarExportInFile_1.removeVarExportInFile(path_1.default.join(dest, './src/config.ts'), varExportsToRemove);
    // We don't touch vite-env.d.ts to simplify the process a bit
    replaceStringValueInFile_1.replaceStringValueInFile(path_1.default.join(dest, './vite.config.ts'), 'AMPLICODE_ENDPOINTS', 'graphql');
    npmDeps_1.removeNpmDeps(path_1.default.join(dest, 'package.json'), Object.keys(auth_oidc_keycloak_1.OIDC_KEYCLOAK_AUTH_DEPS));
}
exports.raResetAuth = raResetAuth;
function deleteFileSync(filePath) {
    console.log("raResetAuth: delete file ", filePath);
    fs_1.default.rmSync(filePath, { force: true, recursive: true });
}
//# sourceMappingURL=raResetAuth.js.map