"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.composeScreenImportPath = exports.writeScreenToAdminUi = void 0;
const path_1 = __importDefault(require("path"));
const addScreenToAdminUi_1 = require("../../../building-blocks/stages/writing/pieces/resource/addScreenToAdminUi");
function writeScreenToAdminUi(gen, screenPaths, entityName, screenName, screenType) {
    const appTsxFilePath = path_1.default.join(screenPaths.srcPath, 'app', 'App.tsx');
    const screenImportPath = composeScreenImportPath(screenPaths.relativeDestPath);
    if (!gen.fs.exists(appTsxFilePath)) {
        gen.log(`Unable to add screen to AdminUI, App.tsx file not found in path '${appTsxFilePath}'`);
    }
    else {
        const appContents = gen.fs.read(appTsxFilePath);
        const appTransformed = addScreenToAdminUi_1.addScreenToAdminUi(appContents, entityName, screenName, screenType, screenImportPath);
        gen.fs.write(appTsxFilePath, appTransformed);
        gen.log(`Screen '${screenType}:${screenName}' added to AdminUI tag in '${appTsxFilePath}'`);
    }
}
exports.writeScreenToAdminUi = writeScreenToAdminUi;
function composeScreenImportPath(relativeScreenPath) {
    // In case that we add import to file App.tsx, which located in `app` directory
    // we can shorten import path started from "../app" to "./"
    return relativeScreenPath.startsWith("app/")
        ? relativeScreenPath.replace(/app\//, "./")
        : path_1.default.join("..", relativeScreenPath);
}
exports.composeScreenImportPath = composeScreenImportPath;
//# sourceMappingURL=writeScreenToAdminUi.js.map