"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveFilterModel = void 0;
const graphql_1 = require("graphql");
const getGraphQLTypeByArgumentName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getGraphQLTypeByArgumentName");
const isAnyLeafType_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/isAnyLeafType");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const change_case_1 = require("change-case");
function deriveFilterModel(queryName, filterByArguments, schema) {
    console.log(`deriveFilterModel: query name '${queryName}', filterByArguments '${JSON.stringify(filterByArguments)}'`);
    let filters = [];
    if (Array.isArray(filterByArguments) && filterByArguments.length > 0) {
        const listQueryType = schema.getQueryType()?.getFields()[queryName];
        if (listQueryType == null)
            throw new Error('Can\'t find query name in the schema for generating filters');
        filters = filterByArguments.map(argumentName => {
            const gqlType = getGraphQLTypeByArgumentName_1.getGraphQLTypeByArgumentName(schema, listQueryType, argumentName);
            const type = graphql_1.getNamedType(gqlType).toString();
            if (argumentName == null || argumentName.length < 1) {
                throw new Error(`Argument name array should contain at least one element, but found ${argumentName}`);
            }
            const name = argumentName.at(-1);
            return {
                kind: 'gql',
                name,
                displayName: change_case_1.capitalCase(name),
                type,
                gqlType,
                enumOptions: gqlType instanceof graphql_1.GraphQLEnumType
                    ? gqlType.getValues()
                    : undefined,
                isSingleRelationField: !isAnyLeafType_1.isAnyLeafType(gqlType) && !(gqlType instanceof graphql_1.GraphQLList),
                isMultiRelationField: !isAnyLeafType_1.isAnyLeafType(gqlType) && gqlType instanceof graphql_1.GraphQLList,
                nestedAttributes: isAnyLeafType_1.isAnyLeafType(gqlType)
                    ? undefined
                    : getAttributeNames_1.getAttributeNames(type, schema),
            };
        });
    }
    const withFilters = filters.length > 0;
    return {
        filters,
        withFilters,
    };
}
exports.deriveFilterModel = deriveFilterModel;
//# sourceMappingURL=deriveFilterModel.js.map