"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const deriveFilterModel_1 = require("./deriveFilterModel");
const test_commons_1 = require("../../../test/test-commons");
const chai_1 = require("chai");
describe("deriveFilterModel", function () {
    let schema;
    before(async () => {
        schema = await test_commons_1.getMockSchema();
    });
    it("should derive correct gql type for filter", function () {
        const filterByArguments = [
            "bigDecimalNotNullMin",
            "bigIntNotNullMin",
            "dateTestNotNullMin",
            "localDateNotNullMax",
            "localDateTimeNotNullMin",
            "localTimeNotNull",
            "offsetDateTimeNotNullMax",
            "offsetDateTimeNotNullMin",
            "offsetTimeNotNullMax",
            "stringNotNull",
            "urlNotNull"
        ];
        const filterModel = deriveFilterModel_1.deriveFilterModel('notNullScalarsTestEntityListWithFilterSortPage', filterByArguments.map(filter => ["filter", filter]), schema);
        chai_1.expect(filterModel.filters.find(fl => fl.name === "urlNotNull").type).to.eq("Url");
        chai_1.expect(filterModel.filters.find(fl => fl.name === "offsetDateTimeNotNullMin").type).to.eq("DateTime");
        chai_1.expect(filterModel.filters.find(fl => fl.name === "localTimeNotNull").type).to.eq("LocalTime");
    });
});
//# sourceMappingURL=deriveFilterModel.test.js.map