"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveAdvancedListModel = void 0;
const graphql_1 = require("graphql");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getOperationDefinitionName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getOperationDefinitionName");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const change_case_1 = require("change-case");
const utils_1 = require("../../../common/utils");
const deriveFilterModel_1 = require("./deriveFilterModel");
const reactAdminUtilModel_1 = require("../common/reactAdminUtilModel");
const deriveAdvancedListModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error("Schema not found");
    }
    const { componentName, listQuery: queryString, deleteMutation: deleteMutationString, orderByArguments, filterByArguments, paginationArgument, } = answers;
    const queryNode = graphql_tag_1.default(queryString);
    const mutationNode = deleteMutationString != null ? graphql_tag_1.default(deleteMutationString) : undefined;
    const queryName = getTopFieldName_1.getTopFieldName(queryNode);
    const refetchQuery = getOperationDefinitionName_1.getOperationDefinitionName(queryNode);
    const deleteMutationName = mutationNode != null ? getTopFieldName_1.getTopFieldName(mutationNode) : undefined;
    const attributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema, "id");
    const entityName = getEntityName_1.getEntityName(queryName, schema);
    const allAttributes = getAttributeNames_1.getAttributeNames(entityName, schema);
    const sortableAttrs = orderByArguments == null
        ? []
        : orderByArguments.map(arg => change_case_1.camelCase(arg));
    const { filters, withFilters } = deriveFilterModel_1.deriveFilterModel(queryName, filterByArguments == null ? [] : filterByArguments, schema);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...reactAdminUtilModel_1.reactAdminUtilModel,
        relDirShift: utils_1.normalizeRelativePath(options.dirShift),
        schema: schema ? graphql_1.printSchema(schema, { commentDescriptions: true }) : undefined,
        componentName,
        queryName,
        queryString,
        deleteMutationName,
        deleteMutationString,
        attributes,
        allAttributes,
        sortableAttrs,
        refetchQuery,
        entityName,
        filters,
        withFilters,
        resultDataPath: getResultDataPath(queryNode),
        withPagination: !utils_1.isBlank(paginationArgument),
        paginationArgument: paginationArgument,
    };
};
exports.deriveAdvancedListModel = deriveAdvancedListModel;
/**
 * Result data path - path in query result where entity list is stored.
 * Returns 'content' for paging queries, or empty string in other cases.
 * @param documentNode query to be checked
 */
function getResultDataPath(documentNode) {
    const operation = documentNode.definitions[0];
    if (operation.kind !== 'OperationDefinition')
        throw new Error('Operation definition not found');
    const topField = operation.selectionSet.selections[0];
    if (topField.kind !== 'Field')
        throw new Error('topField can be only Field kind');
    const selectedFields = topField.selectionSet?.selections;
    if (selectedFields == null)
        throw new Error('Fields from topField aren\'t found');
    const content = selectedFields
        .find(field => field.kind === "Field"
        && field.name.value === "content"
        && Array.isArray(field.selectionSet?.selections));
    const totalElements = selectedFields
        .find(field => field.kind === "Field"
        && field.name.value === "totalElements");
    if (content != null
        && content.kind === 'Field'
        && content.selectionSet != null
        && totalElements != null) {
        return 'content';
    }
    return '';
}
//# sourceMappingURL=template-model.js.map