import React, {PropsWithChildren, useEffect,useState} from "react";
import {SecurityContext} from "./SecurityContext";
import {SecurityStore} from "./SecurityStore";
import {useApolloClient} from "@apollo/client";
import {Loading} from "../feedback/Loading";

export function SecurityProvider({children}: PropsWithChildren<unknown>) {
  return (
    <SecurityStoreProvider>
      {children}
    </SecurityStoreProvider>
  );
}

function SecurityStoreProvider({children}: PropsWithChildren<unknown>) {
  const client = useApolloClient();

  const [securityStore, setSecurityStore] = useState<SecurityStore | undefined>();

  useEffect(() => {
    if (securityStore == null) {
      setSecurityStore(new SecurityStore(client));
    }
  }, [client, securityStore]);

  if (securityStore == null) {
    return <Loading/>;
  }

  return (
    <SecurityContext.Provider value={securityStore}>
      {children}
    </SecurityContext.Provider>
  );
}
