import { action, makeObservable, observable } from "mobx";
import { LOGOUT_URI, LOGIN_URI } from "../../config";
import { ApolloClient, gql } from "@apollo/client";

export class SecurityStore {
  @observable isLoggedIn: boolean = true;
  @observable userName: string | null = null;

  constructor(private client: ApolloClient<unknown>) {
    makeObservable(this);
  }

  @action
  login = () => {
    window.location.href = `${LOGIN_URI}?redirect_uri=${window.location.href}`;
  };

  @action
  logout = () => {
    window.location.href = `${LOGOUT_URI}?redirect_uri=${window.location.href}`;
  };

  @action
  initialize = (): Promise<void> => {
    return this.client
    .query({
      query: gql`
        query {
          userInfo {
            username
          }
        }
      `
    })
    .then(
      action(resp => {
        const {
          userInfo: { username }
        } = resp.data;
        this.userName = username;
        this.isLoggedIn = true;
      })
    )
    .catch(
      action(() => {
        this.isLoggedIn = false;
      })
    );
  };
}