import { DocumentNode, GraphQLSchema } from "graphql";
export interface ClientValidationRuleMapping {
    [attribute: string]: ClientValidationRule[];
}
export declare type ClientValidationRule = {
    rule: 'assertFalse';
} | {
    rule: 'assertTrue';
} | {
    rule: 'decimalMax';
    value: string;
    inclusive: boolean;
} | {
    rule: 'decimalMin';
    value: string;
    inclusive: boolean;
} | {
    rule: 'digits';
    integer: number;
    fraction: number;
} | {
    rule: 'email';
    regexp: string;
} | {
    rule: 'futureOrPresent';
    type: 'date' | 'instant';
} | {
    rule: 'future';
    type: 'date' | 'instant';
} | {
    rule: 'max';
    value: number;
} | {
    rule: 'min';
    value: number;
} | {
    rule: 'negative';
} | {
    rule: 'negativeOrZero';
} | {
    rule: 'notBlank';
} | {
    rule: 'notEmpty';
} | {
    rule: 'notNull';
} | // based on scalar nullability rather than directive
{
    rule: 'null';
} | {
    rule: 'past';
    type: 'date' | 'instant';
} | {
    rule: 'pastOrPresent';
    type: 'date' | 'instant';
} | {
    rule: 'pattern';
    regexp: string;
} | {
    rule: 'positive';
} | {
    rule: 'positiveOrZero';
} | {
    rule: 'size';
    min: number;
    max: number;
    isList: boolean;
} | {
    rule: 'length';
    min: number;
    max: number;
} | {
    rule: 'url';
};
export declare function deriveClientValidationRules(node?: DocumentNode, schema?: GraphQLSchema): {
    clientValidationRules: ClientValidationRuleMapping;
    validatorImports: string[];
};
/**
 * Returns undefined when directive doesn't require custom Antd validator
 *
 * @param directiveName
 * @param ruleType
 */
export declare function getValidatorImport(directiveName: string, ruleType?: 'date' | 'instant'): string | undefined;
