"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveType = exports.deriveMode = exports.derivePatinationTemplateModel = exports.deriveOrderByTemplateModel = exports.deriveFiltersTemplateModel = exports.deriveEntityListTemplateModel = void 0;
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const graphql_1 = require("graphql");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const ScreenTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/ScreenTemplateModel");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getOperationDefinitionName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getOperationDefinitionName");
const getGraphQLTypeByArgumentName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getGraphQLTypeByArgumentName");
const utils_1 = require("../../../common/utils");
const template_model_1 = require("../entity-details/template-model");
const isAnyLeafType_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/isAnyLeafType");
const deriveEntityListTemplateModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error('Schema not found');
    }
    const { componentName, route, query: queryString, mutation: deleteMutationString, type = 'Cards', multiselect = false, mode = 'Edit', idField = 'id', filterByArguments, orderByArguments, paginationType } = answers;
    const queryNode = graphql_tag_1.default(queryString);
    const mutationNode = deleteMutationString != null ? graphql_tag_1.default(deleteMutationString) : undefined;
    const queryName = getTopFieldName_1.getTopFieldName(queryNode);
    const refetchQuery = getOperationDefinitionName_1.getOperationDefinitionName(queryNode);
    const deleteMutationName = mutationNode != null ? getTopFieldName_1.getTopFieldName(mutationNode) : undefined;
    const attributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema, idField);
    const entityName = getEntityName_1.getEntityName(queryName, schema);
    const allAttributes = getAttributeNames_1.getAttributeNames(entityName, schema);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...util_1.templateUtilities,
        ...ScreenTemplateModel_1.deriveScreenTemplateModel(options, answers, schema),
        ...deriveFiltersTemplateModel(queryName, filterByArguments, schema),
        ...deriveOrderByTemplateModel(queryName, orderByArguments, schema),
        ...derivePatinationTemplateModel(queryName, paginationType, schema),
        componentName,
        route,
        queryName,
        queryString,
        deleteMutationName,
        deleteMutationString,
        attributes,
        allAttributes,
        idField,
        type: deriveType(type),
        multiselect,
        mode: deriveMode(mode),
        refetchQuery,
        entityName
    };
};
exports.deriveEntityListTemplateModel = deriveEntityListTemplateModel;
function deriveFiltersTemplateModel(queryName, filterByArguments, schema) {
    let filters = [];
    if (filterByArguments != null) {
        const listQueryType = schema.getQueryType()?.getFields()[queryName];
        if (listQueryType == null)
            throw new Error('Can\'t find query name in the schema for generating filters');
        filters = filterByArguments.map(argumentName => {
            const gqlType = getGraphQLTypeByArgumentName_1.getGraphQLTypeByArgumentName(schema, listQueryType, argumentName);
            const type = graphql_1.getNamedType(gqlType).toString();
            return {
                kind: 'gql',
                name: argumentName.length === 1 ? argumentName[0] : argumentName,
                displayName: getFilterCaption(argumentName),
                type,
                gqlType,
                enumOptions: gqlType instanceof graphql_1.GraphQLEnumType
                    ? gqlType.getValues()
                    : undefined,
                isSingleRelationField: !isAnyLeafType_1.isAnyLeafType(gqlType) && !(gqlType instanceof graphql_1.GraphQLList),
                isMultiRelationField: !isAnyLeafType_1.isAnyLeafType(gqlType) && gqlType instanceof graphql_1.GraphQLList,
                nestedAttributes: isAnyLeafType_1.isAnyLeafType(gqlType)
                    ? undefined
                    : getAttributeNames_1.getAttributeNames(type, schema),
            };
        });
    }
    const withFilters = filters.length > 0;
    const filterUsingScalars = template_model_1.deriveUsingScalars(filters);
    const maxFiltersInRow = 4;
    const hiddenFilters = filters.filter((_, index) => index >= maxFiltersInRow);
    const withHiddenFilters = hiddenFilters.length > 0;
    return {
        filterUsingScalars,
        filters,
        withFilters,
        hiddenFilters,
        withHiddenFilters,
        maxFiltersInRow,
    };
}
exports.deriveFiltersTemplateModel = deriveFiltersTemplateModel;
function getFilterCaption(argumentName) {
    return removeFirstFilterPathString(argumentName)
        .map(argumentNameElem => utils_1.capitalizeFirst(utils_1.splitByCapitalLetter(argumentNameElem)))
        .join(' ');
}
function removeFirstFilterPathString(argumentName) {
    if (argumentName[0] === 'filter' && argumentName.length > 1) {
        const [, ...tail] = argumentName;
        return tail;
    }
    return argumentName;
}
function deriveOrderByTemplateModel(queryName, orderByArguments, schema) {
    let orderByType;
    let sortPropertyType;
    let sortDirectionType;
    const withOrderBy = orderByArguments != null && orderByArguments.length > 0;
    if (withOrderBy) {
        const listQueryType = schema.getQueryType()?.getFields()[queryName];
        if (listQueryType == null)
            throw new Error('Can\'t find query name in the schema for generating filters');
        const orderByGQLType = listQueryType.args.find(e => e.name === 'sort')?.type;
        if (orderByGQLType == null) {
            throw new Error('orderByArguments were provided in answers, but "sort" argument is not found in query');
        }
        const orderByNamedType = graphql_1.getNamedType(orderByGQLType);
        if (!('getFields' in orderByNamedType)) {
            throw new Error('Cannot find direction/property types in orderBy input type');
        }
        const fields = orderByNamedType.getFields();
        const propertyScalarType = fields['property']?.type;
        const directionScalarType = fields['direction']?.type;
        if (!('name' in propertyScalarType)) {
            throw new Error(`Cannot find name in scalar type ${propertyScalarType}`);
        }
        if (!('name' in directionScalarType)) {
            throw new Error(`Cannot find name in scalar type ${directionScalarType}`);
        }
        sortPropertyType = propertyScalarType.name;
        sortDirectionType = directionScalarType.name;
        orderByType = orderByNamedType.toString();
    }
    return {
        sortPropertyType,
        sortDirectionType,
        orderByArguments,
        orderByType,
        withOrderBy
    };
}
exports.deriveOrderByTemplateModel = deriveOrderByTemplateModel;
function derivePatinationTemplateModel(queryName, paginationType, schema) {
    const listQueryType = schema.getQueryType()?.getFields()[queryName];
    if (listQueryType == null)
        throw new Error('Can\'t find query name in the schema for generating filters');
    return {
        paginationType,
        withPagination: paginationType != null
    };
}
exports.derivePatinationTemplateModel = derivePatinationTemplateModel;
function deriveMode(mode) {
    switch (mode) {
        case 'Edit':
            return 'edit';
        case 'Details':
            return 'view with details';
        case 'None':
            return 'view';
    }
}
exports.deriveMode = deriveMode;
function deriveType(type) {
    switch (type) {
        case 'Cards':
            return 'cards';
        case 'List':
            return 'list';
        case 'Table':
            return 'table';
        default:
            throw new Error(`deriveType: unsupported type '${type}', expected: Cards, List, Table`);
    }
}
exports.deriveType = deriveType;
//# sourceMappingURL=template-model.js.map