"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.commonEntityManagementQuestions = void 0;
exports.commonEntityManagementQuestions = [
    {
        caption: 'Query to load items',
        code: 'listQuery',
        propertyType: "GRAPHQL_QUERY" /* GRAPHQL_QUERY */,
        required: true,
        step: {
            name: "Entity Management",
            order: "1"
        }
    },
    {
        caption: 'Mutation to delete an item',
        code: 'deleteMutation',
        propertyType: "GRAPHQL_MUTATION" /* GRAPHQL_MUTATION */,
        relatedProperty: 'listQuery',
        required: false,
        step: {
            name: "Entity Management",
            order: "2"
        }
    },
    {
        caption: 'Query to load item',
        code: 'detailsQuery',
        propertyType: "GRAPHQL_QUERY" /* GRAPHQL_QUERY */,
        required: true,
        step: {
            name: "Entity Management",
            order: "3"
        }
    },
    {
        caption: 'Mutation to create or update item',
        code: 'upsertMutation',
        propertyType: "GRAPHQL_MUTATION" /* GRAPHQL_MUTATION */,
        relatedProperty: 'detailsQuery',
        required: false,
        step: {
            name: "Entity Management",
            order: "4"
        }
    },
    {
        caption: 'List component name',
        code: 'listComponentName',
        propertyType: "POLYMER_COMPONENT_NAME" /* POLYMER_COMPONENT_NAME */,
        relatedProperty: 'listQuery',
        defaultValue: 'List',
        required: true,
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'List component route',
        code: 'route',
        propertyType: "ROUTE" /* ROUTE */,
        required: true,
        relatedProperty: 'listComponentName',
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Details component name',
        code: 'itemComponentName',
        propertyType: "POLYMER_COMPONENT_NAME" /* POLYMER_COMPONENT_NAME */,
        relatedProperty: 'detailsQuery',
        defaultValue: 'Details',
        required: true,
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Details action mode',
        // description: 'Possible values: ' +
        //   '"Edit" (there will be buttons to create and edit entity), ' +
        //   '"Details" (read-only, there will be a button to view entity details). ' +
        //   'Presence of delete button depends on whether delete mutation has been provided.',
        code: 'mode',
        propertyType: "RADIO" /* RADIO */,
        defaultValue: 'Edit',
        options: ['Edit', 'Details'],
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Entity list type',
        code: 'type',
        propertyType: "ADVANCED_RADIO" /* ADVANCED_RADIO */,
        defaultValue: 'Cards',
        options: ['Cards', 'List', 'Table'],
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Multiselect',
        code: 'multiselect',
        propertyType: "BOOLEAN" /* BOOLEAN */,
        defaultValue: false,
        showIf: {
            type: 'Table'
        },
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Name of list id attribute',
        code: 'listIdField',
        propertyType: "OPTION" /* OPTION */,
        relatedProperty: 'listQuery',
        required: false,
        options: [],
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: 'Name of details id attribute',
        code: 'detailsIdField',
        propertyType: "OPTION" /* OPTION */,
        relatedProperty: 'detailsQuery',
        required: false,
        options: [],
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
    {
        caption: "Select arguments to filter by",
        code: "filterByArguments",
        propertyType: "FILTER_QUERY_ARGUMENT_ARRAY" /* FILTER_QUERY_ARGUMENT_ARRAY */,
        relatedProperty: 'listQuery',
        required: false,
        step: {
            name: "Entity Management",
            order: "5",
        }
    },
    {
        caption: "Select arguments to order by",
        code: "orderByArguments",
        propertyType: "ORDER_QUERY_ARGUMENT_ARRAY" /* ORDER_QUERY_ARGUMENT_ARRAY */,
        relatedProperty: 'listQuery',
        required: false,
        step: {
            name: "Entity Management",
            order: "5",
        }
    },
    {
        caption: "Pagination type",
        code: "paginationType",
        propertyType: "PAGINATION_TYPE" /* PAGINATION_TYPE */,
        relatedProperty: 'listQuery',
        required: false,
        step: {
            name: "Entity Management",
            order: "5",
        }
    },
    {
        caption: "Add to menu",
        code: "shouldAddToMenu",
        propertyType: "BOOLEAN" /* BOOLEAN */,
        defaultValue: true,
        required: true,
        step: {
            name: "Entity Management",
            order: "5"
        }
    },
];
//# sourceMappingURL=answers.js.map