"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveInsertedListFromGqlTemplateModel = void 0;
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const graphql_1 = require("graphql");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const amplicodeGetMetadata_1 = require("../../../building-blocks/stages/metadata/amplicodeGetMetadata");
const utils_1 = require("../../../common/utils");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getOperationDefinitionName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getOperationDefinitionName");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const template_model_1 = require("../entity-list/template-model");
const deriveInsertedListFromGqlTemplateModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error('Schema not found');
    }
    const { idField = 'id', editButtons = false, query: queryString, filterByArguments, orderByArguments, paginationType } = answers;
    const metadata = await amplicodeGetMetadata_1.amplicodeGetMetadata(options);
    const relDirShift = utils_1.normalizeRelativePath(options.dirShift);
    const { responseFile } = options;
    if (responseFile == null)
        throw new Error('Path for generating file with response not found');
    const queryNode = graphql_tag_1.default(queryString);
    const queryName = getTopFieldName_1.getTopFieldName(queryNode);
    const refetchQuery = getOperationDefinitionName_1.getOperationDefinitionName(queryNode);
    const attributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema, idField);
    const entityName = getEntityName_1.getEntityName(queryName, schema);
    const allAttributes = getAttributeNames_1.getAttributeNames(entityName, schema);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...util_1.templateUtilities,
        ...template_model_1.deriveFiltersTemplateModel(queryName, filterByArguments, schema),
        ...template_model_1.deriveOrderByTemplateModel(queryName, orderByArguments, schema),
        ...template_model_1.derivePatinationTemplateModel(queryName, paginationType, schema),
        entityName,
        queryName,
        queryString,
        attributes,
        allAttributes,
        idField,
        refetchQuery,
        studioVars: metadata.variables,
        responseFile,
        withEditButtons: editButtons,
        relDirShift,
        schema: schema ? graphql_1.printSchema(schema, { commentDescriptions: true }) : undefined,
    };
};
exports.deriveInsertedListFromGqlTemplateModel = deriveInsertedListFromGqlTemplateModel;
//# sourceMappingURL=template-model.js.map