"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = exports.readClient = exports.collectClients = void 0;
const fs_1 = require("fs");
const yeoman_environment_1 = __importDefault(require("yeoman-environment"));
const path_1 = __importDefault(require("path"));
const fs = __importStar(require("fs"));
const GENERATORS_DIR_NAME = 'generators';
const GENERATOR_FILE_NAME = 'index.js';
const INFO_FILE_NAME = 'info.json';
function collectClients(generatorFileName, opts) {
    const { customGeneratorPaths, } = opts ?? {};
    const clients = collectBundledGenerators(generatorFileName);
    collectGeneratorsFromProject(clients);
    collectGeneratorsFromCustomPaths(clients, customGeneratorPaths);
    return clients;
}
exports.collectClients = collectClients;
function collectBundledGenerators(generatorFileName) {
    const clientsDirPath = path_1.default.join(__dirname, GENERATORS_DIR_NAME);
    return readClientDir(clientsDirPath, generatorFileName);
}
function collectGeneratorsFromProject(clients) {
    const PROJECT_CLIENTS_RELATIVE_PATH = '../../../../generators';
    const projectClientsPath = path_1.default.join(__dirname, PROJECT_CLIENTS_RELATIVE_PATH);
    if (!fs.existsSync(projectClientsPath)) {
        return;
    }
    collectFromPath(clients, projectClientsPath);
}
function collectFromPath(clients, customPath) {
    const customClientArray = readClientDir(customPath);
    for (const customClient of customClientArray) {
        const clientIndex = clients.findIndex(c => c.name === customClient.name);
        if (clientIndex > -1) {
            // We already have such client, so we merge generators
            clients[clientIndex].generators.push(...customClient.generators);
            continue;
        }
        // We don't already have such client, so we push it
        clients.push(customClient);
    }
}
function collectGeneratorsFromCustomPaths(clients, customGeneratorPaths) {
    if (customGeneratorPaths == null) {
        // No custom generators to be added
        return;
    }
    for (const customPath of customGeneratorPaths) {
        collectFromPath(clients, customPath);
    }
}
function readClientDir(clientsDirPath, generatorFileName) {
    return fs_1.readdirSync(clientsDirPath).map((clientDirName) => {
        return readClient(clientsDirPath, clientDirName, generatorFileName);
    });
}
/**
 * @alpha
 */
function readClient(clientsDirPath, clientDirName, generatorFileName) {
    const info = require(path_1.default.join(clientsDirPath, clientDirName, INFO_FILE_NAME));
    return {
        bundled: true,
        name: clientDirName,
        bower: info.bower,
        clientBaseTech: info.clientBaseTech,
        generators: collectGenerators(path_1.default.join(clientsDirPath, clientDirName), generatorFileName),
    };
}
exports.readClient = readClient;
async function generate(generatorPath, options, templateOverride) {
    const env = new yeoman_environment_1.default();
    const { generator } = await Promise.resolve().then(() => __importStar(require(generatorPath)));
    env.registerStub(generator, generator.name);
    return env.run(generator.name, {
        templateOverride,
        ...options
    });
}
exports.generate = generate;
function collectGenerators(generatorsDir, genFileName = GENERATOR_FILE_NAME) {
    const dirs = fs_1.readdirSync(generatorsDir);
    return sortGenerators(dirs.reduce((generators, generatorDirName) => {
        const generatorPath = path_1.default.join(generatorsDir, generatorDirName);
        if (fs_1.existsSync(path_1.default.join(generatorPath, genFileName)) && fs_1.statSync(generatorPath).isDirectory()) {
            const generatorExports = require(generatorPath);
            if (generatorExports.generator == null) {
                return generators;
            }
            const options = generatorExports.options;
            const params = generatorExports.params;
            const name = generatorExports.name ?? generatorDirName;
            const caption = generatorExports.caption;
            const description = generatorExports.description;
            const index = generatorExports.index ?? dirs.length; // will be pushed to a tail if no index
            const isFrontendComponent = generatorExports.isFrontendComponent !== false; // set to true, if this param not defined
            const iconPath = generatorExports.icon
                ? path_1.default.relative(process.cwd(), path_1.default.join(generatorPath, generatorExports.icon))
                : undefined;
            generators.push({ name, caption: caption ?? name, options, params, description, iconPath, index, path: generatorPath, isFrontendComponent });
            return generators;
        }
        else {
            return generators;
        }
    }, []));
}
function sortGenerators(generators) {
    return generators.slice().sort((a, b) => a.index - b.index);
}
//# sourceMappingURL=init.js.map