"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const init_1 = require("../init");
const chai_1 = require("chai");
describe('init', function () {
    let client;
    before(() => {
        client = init_1.collectClients('index.ts')[1];
    });
    it('should collect clients', function () {
        const clients = init_1.collectClients('index.ts')
            .sort((a, b) => a.name.localeCompare(b.name));
        chai_1.expect(clients.length).to.eq(2);
        const genCountOfClient = new Map();
        genCountOfClient.set('react-typescript', 14);
        genCountOfClient.forEach((num, client) => chai_1.expect(clients.find(c => c.name == client).generators.length).eq(num));
    });
    it('frontend component generators ordering is correct', () => {
        const generatorsOrdering = client.generators
            .filter(g => g.isFrontendComponent)
            .sort((a, b) => {
            return a.index - b.index;
        })
            .map(g => g.name);
        chai_1.expect(generatorsOrdering).to.deep.eq([
            'blank',
            'entity-management',
            'entity-lookup',
            'entity-list-cards',
            'entity-list-table',
            'entity-list-list',
            'entity-details'
        ]);
    });
    it('blank generator should have params expected by Studio', () => {
        const params = getParams(client, 'blank');
        const componentName = findParam(params, 'componentName');
        expectStep(componentName, 'Blank', '1');
        const shouldAddToMenu = findParam(params, 'shouldAddToMenu');
        expectStep(shouldAddToMenu, 'Blank', '1');
        const route = findParam(params, 'route');
        expectStep(route, 'Blank', '1');
    });
    it('entity-management generator should have params expected by Studio', () => {
        const params = getParams(client, 'entity-management');
        const paramsOrder = getParamsOrder(params);
        chai_1.expect(paramsOrder).to.deep.eq([
            'listQuery',
            'deleteMutation',
            'detailsQuery',
            'upsertMutation',
            // step 5:
            'listComponentName', 'route', 'itemComponentName', 'mode',
            'type', 'multiselect',
            'listIdField', 'detailsIdField',
            'filterByArguments', 'orderByArguments', 'paginationType',
            'shouldAddToMenu'
        ]);
        const listQuery = findParam(params, 'listQuery');
        expectStep(listQuery, 'Entity Management', '1');
        const deleteMutation = findParam(params, 'deleteMutation');
        chai_1.expect(deleteMutation?.relatedProperty).to.eq('listQuery');
        expectStep(deleteMutation, 'Entity Management', '2');
        const detailsQuery = findParam(params, 'detailsQuery');
        expectStep(detailsQuery, 'Entity Management', '3');
        const upsertMutation = findParam(params, 'upsertMutation');
        chai_1.expect(upsertMutation?.relatedProperty).to.eq('detailsQuery');
        expectStep(upsertMutation, 'Entity Management', '4');
        const listComponentName = findParam(params, 'listComponentName');
        chai_1.expect(listComponentName?.relatedProperty).to.eq('listQuery');
        expectStep(listComponentName, 'Entity Management', '5');
        const route = findParam(params, 'route');
        expectStep(route, 'Entity Management', '5');
        const itemComponentName = findParam(params, 'itemComponentName');
        chai_1.expect(itemComponentName?.relatedProperty).to.eq('detailsQuery');
        expectStep(itemComponentName, 'Entity Management', '5');
        const mode = findParam(params, 'mode');
        chai_1.expect(mode?.caption).to.eq('Details action mode');
        chai_1.expect(mode?.propertyType).to.eq("RADIO" /* RADIO */);
        chai_1.expect(mode?.defaultValue).to.eq('Edit');
        chai_1.expect(mode?.options).to.deep.eq(['Edit', 'Details']);
        expectStep(mode, 'Entity Management', '5');
        const type = findParam(params, 'type');
        chai_1.expect(type?.propertyType).to.eq("ADVANCED_RADIO" /* ADVANCED_RADIO */);
        chai_1.expect(type?.defaultValue).to.eq('Cards');
        chai_1.expect(type?.options).to.deep.eq(['Cards', 'List', 'Table']);
        expectStep(type, 'Entity Management', '5');
        const listIdField = findParam(params, 'listIdField');
        chai_1.expect(listIdField?.caption).to.eq('Name of list id attribute');
        chai_1.expect(listIdField?.relatedProperty).to.eq('listQuery');
        chai_1.expect(listIdField?.propertyType).to.eq("OPTION" /* OPTION */);
        chai_1.expect(listIdField?.defaultValue).to.be.undefined;
        chai_1.expect(listIdField?.options).to.deep.eq([]);
        expectStep(listIdField, 'Entity Management', '5');
        const detailsIdField = findParam(params, 'detailsIdField');
        chai_1.expect(detailsIdField?.caption).to.eq('Name of details id attribute');
        chai_1.expect(detailsIdField?.relatedProperty).to.eq('detailsQuery');
        chai_1.expect(detailsIdField?.propertyType).to.eq("OPTION" /* OPTION */);
        chai_1.expect(detailsIdField?.defaultValue).to.be.undefined;
        chai_1.expect(detailsIdField?.options).to.deep.eq([]);
        expectStep(detailsIdField, 'Entity Management', '5');
        const filterByArguments = findParam(params, 'filterByArguments');
        expectStep(filterByArguments, 'Entity Management', '5');
        const orderByArguments = findParam(params, 'orderByArguments');
        chai_1.expect(orderByArguments.relatedProperty).to.eq(listQuery.code);
        expectStep(orderByArguments, 'Entity Management', '5');
        const paginationType = findParam(params, 'paginationType');
        chai_1.expect(paginationType.relatedProperty).to.eq(listQuery.code);
        expectStep(paginationType, 'Entity Management', '5');
        const shouldAddToMenu = findParam(params, 'shouldAddToMenu');
        expectStep(shouldAddToMenu, 'Entity Management', '5');
    });
    it('entity-list-cards generator should have params expected by Studio', () => {
        const p = getParams(client, 'entity-list-cards');
        const paramsOrder = getParamsOrder(p);
        chai_1.expect(paramsOrder).to.deep.eq([
            'query',
            'mutation',
            // step 3:
            'componentName', 'route', 'mode', 'idField',
            'filterByArguments', 'orderByArguments', 'paginationType',
            'shouldAddToMenu'
        ]);
        chai_1.expect(p.find(param => param.code === 'multiselect')).to.be.undefined;
        expectEntityList(p);
    });
    it('entity-list-list generator should have params expected by Studio', () => {
        const p = getParams(client, 'entity-list-list');
        const paramsOrder = getParamsOrder(p);
        chai_1.expect(paramsOrder).to.deep.eq([
            'query',
            'mutation',
            // step 3:
            'componentName', 'route', 'mode', 'idField',
            'filterByArguments', 'orderByArguments', 'paginationType',
            'shouldAddToMenu'
        ]);
        chai_1.expect(p.find(param => param.code === 'multiselect')).to.be.undefined;
        expectEntityList(p);
    });
    it('entity-list-table generator should have params expected by Studio', () => {
        const p = getParams(client, 'entity-list-table');
        const paramsOrder = getParamsOrder(p);
        chai_1.expect(paramsOrder).to.deep.eq([
            'query',
            'mutation',
            // step 3:
            'componentName', 'route', 'mode', 'multiselect', 'idField',
            'filterByArguments', 'orderByArguments', 'paginationType',
            'shouldAddToMenu'
        ]);
        const multiselect = findParam(p, 'multiselect');
        chai_1.expect(multiselect.showIf).to.be.undefined;
        expectStep(multiselect, 'Entity List', '3');
        expectEntityList(p);
    });
    it('entity-lookup generator should have params expected by Studio', () => {
        const p = getParams(client, 'entity-lookup');
        const stepName = 'Entity Lookup';
        const query = findParam(p, 'query');
        expectStep(query, stepName, '1');
        const componentName = findParam(p, 'componentName');
        chai_1.expect(componentName?.relatedProperty).to.eq('query');
        expectStep(componentName, stepName, '2');
        const route = findParam(p, 'route');
        expectStep(route, stepName, '2');
        const idField = findParam(p, 'idField');
        chai_1.expect(idField?.propertyType).to.eq("OPTION" /* OPTION */);
        chai_1.expect(idField?.defaultValue).to.be.undefined;
        chai_1.expect(idField?.options).to.deep.eq([]);
        expectStep(idField, stepName, '2');
        const shouldAddToMenu = findParam(p, 'shouldAddToMenu');
        expectStep(shouldAddToMenu, stepName, '2');
    });
    it('entity-details generator should have params expected by Studio', () => {
        const p = getParams(client, 'entity-details');
        const paramsOrder = getParamsOrder(p);
        chai_1.expect(paramsOrder).to.deep.eq([
            'query',
            'mutation',
            'componentName', 'idField' // step3
        ]);
        const stepName = 'Entity Details';
        const query = findParam(p, 'query');
        expectStep(query, stepName, '1');
        const mutation = findParam(p, 'mutation');
        chai_1.expect(mutation.relatedProperty).to.eq('query');
        expectStep(mutation, stepName, '2');
        const componentName = findParam(p, 'componentName');
        chai_1.expect(componentName.relatedProperty).to.eq('query');
        expectStep(componentName, stepName, '3');
        const idField = findParam(p, 'idField');
        chai_1.expect(idField.relatedProperty).to.eq('query');
        chai_1.expect(idField.propertyType).to.eq("OPTION" /* OPTION */);
        chai_1.expect(idField.defaultValue).to.be.undefined;
        chai_1.expect(idField.options).to.deep.eq([]);
        expectStep(idField, stepName, '3');
    });
});
function expectEntityList(p) {
    const query = findParam(p, 'query');
    expectStep(query, 'Entity List', '1');
    const mutation = findParam(p, 'mutation');
    chai_1.expect(mutation?.relatedProperty).to.eq('query');
    expectStep(mutation, 'Entity List', '2');
    const componentName = findParam(p, 'componentName');
    chai_1.expect(componentName?.relatedProperty).to.eq('query');
    expectStep(componentName, 'Entity List', '3');
    const route = findParam(p, 'route');
    expectStep(route, 'Entity List', '3');
    const mode = findParam(p, 'mode');
    chai_1.expect(mode?.propertyType).to.eq("RADIO" /* RADIO */);
    chai_1.expect(mode?.defaultValue).to.eq('Edit');
    chai_1.expect(mode?.options).to.deep.eq([
        'Edit', 'Details', 'None'
    ]);
    expectStep(mode, 'Entity List', '3');
    chai_1.expect(p.find(param => param.code === 'type')).to.be.undefined;
    const idField = findParam(p, 'idField');
    chai_1.expect(idField?.relatedProperty).to.eq('query');
    chai_1.expect(idField?.propertyType).to.eq("OPTION" /* OPTION */);
    chai_1.expect(idField?.defaultValue).to.be.undefined;
    chai_1.expect(idField?.options).to.deep.eq([]);
    expectStep(idField, 'Entity List', '3');
    const filterByArguments = findParam(p, 'filterByArguments');
    expectStep(filterByArguments, 'Entity List', '3');
    const orderByArguments = findParam(p, 'orderByArguments');
    chai_1.expect(orderByArguments.relatedProperty).to.eq(query.code);
    expectStep(orderByArguments, 'Entity List', '3');
    const paginationType = findParam(p, 'paginationType');
    chai_1.expect(paginationType.relatedProperty).to.eq(query.code);
    expectStep(paginationType, 'Entity List', '3');
    const shouldAddToMenu = findParam(p, 'shouldAddToMenu');
    expectStep(shouldAddToMenu, 'Entity List', '3');
}
function expectStep(property, name, order) {
    chai_1.expect(property?.step?.name).to.eq(name);
    chai_1.expect(property?.step?.order).to.eq(order);
}
function getParams(client, generatorName) {
    const { params } = client
        .generators
        .find((gen) => gen.name === generatorName) ?? {};
    if (params == null) {
        chai_1.expect.fail();
        throw new Error();
    }
    return params;
}
function getParamsOrder(params) {
    return params.map(param => param.code);
}
function findParam(params, code) {
    const param = params.find(p => p.code === code);
    if (param == null) {
        chai_1.expect.fail();
        throw new Error();
    }
    return param;
}
//# sourceMappingURL=init.test.js.map